← Back to team overview

maria-developers team mailing list archive

[Branch ~maria-captains/maria/5.1] Rev 2708: Added option --staging-run to mysql-test-run to mark slow, not important tests, to not be run in ...

 

------------------------------------------------------------
revno: 2708
committer: Michael Widenius <monty@xxxxxxxxxxxx>
branch nick: mysql-maria
timestamp: Fri 2009-06-05 18:35:22 +0300
message:
  Added option --staging-run to mysql-test-run to mark slow, not important tests, to not be run in staging trees
  Use MY_MUTEX_INIT_FAST for pool mutex
modified:
  mysql-test/mysql-test-run.pl
  mysql-test/suite/federated/federated_server.test
  mysql-test/suite/maria/t/maria-preload.test
  mysql-test/suite/rpl/t/rpl_optimize.test
  mysql-test/suite/rpl/t/rpl_relayrotate.test
  mysql-test/suite/rpl/t/rpl_row_001.test
  mysql-test/suite/rpl/t/rpl_row_mysqlbinlog.test
  mysql-test/suite/rpl/t/rpl_row_sp003.test
  mysql-test/suite/rpl/t/rpl_start_stop_slave.test
  mysql-test/t/compress.test
  mysql-test/t/count_distinct3.test
  mysql-test/t/index_merge_innodb.test
  mysql-test/t/information_schema_all_engines.test
  mysql-test/t/innodb_mysql.test
  mysql-test/t/pool_of_threads.test
  mysql-test/t/preload.test
  mysql-test/t/ssl.test
  mysql-test/t/ssl_compress.test
  mysql-test/valgrind.supp
  sql/scheduler.cc

=== modified file 'mysql-test/mysql-test-run.pl'
--- mysql-test/suite/federated/federated_server.test	2009-01-22 13:07:58 +0000
+++ mysql-test/suite/federated/federated_server.test	2009-06-05 15:35:22 +0000
@@ -1,5 +1,8 @@
 # WL #3031 This test tests the new servers table as well as
 # if federated can utilise the servers table
+
+# Slow test, don't run during staging part
+-- source include/not_staging.inc
 -- source federated.inc
 
 connection slave;

=== modified file 'mysql-test/suite/maria/t/maria-preload.test'
--- mysql-test/suite/maria/t/maria-preload.test	2008-10-01 12:13:39 +0000
+++ mysql-test/suite/maria/t/maria-preload.test	2009-06-05 15:35:22 +0000
@@ -2,6 +2,8 @@
 # Testing of PRELOAD
 #
 
+# Slow test, don't run during staging part
+-- source include/not_staging.inc
 -- source include/have_maria.inc
 
 --disable_warnings

=== modified file 'mysql-test/suite/rpl/t/rpl_optimize.test'
--- mysql-test/suite/rpl/t/rpl_optimize.test	2008-03-25 13:28:12 +0000
+++ mysql-test/suite/rpl/t/rpl_optimize.test	2009-06-05 15:35:22 +0000
@@ -11,6 +11,8 @@
 # Skipping this test if default engine = ndb
 #####################################
 -- source include/not_ndb_default.inc
+# Slow test, don't run during staging part
+-- source include/not_staging.inc
 -- source include/master-slave.inc
 
 create table t1 (a int not null auto_increment primary key, b int, key(b));

=== modified file 'mysql-test/suite/rpl/t/rpl_relayrotate.test'
--- mysql-test/suite/rpl/t/rpl_relayrotate.test	2007-06-27 12:29:10 +0000
+++ mysql-test/suite/rpl/t/rpl_relayrotate.test	2009-06-05 15:35:22 +0000
@@ -6,6 +6,9 @@
 #######################################################
 -- source include/not_ndb_default.inc
 -- source include/have_innodb.inc
+# Slow test, don't run during staging part
+-- source include/not_staging.inc
 -- source include/master-slave.inc
+
 let $engine_type=innodb;
 -- source extra/rpl_tests/rpl_relayrotate.test

=== modified file 'mysql-test/suite/rpl/t/rpl_row_001.test'
--- mysql-test/suite/rpl/t/rpl_row_001.test	2007-06-27 12:29:10 +0000
+++ mysql-test/suite/rpl/t/rpl_row_001.test	2009-06-05 15:35:22 +0000
@@ -4,6 +4,9 @@
 ########################################################
 -- source include/not_ndb_default.inc
 -- source include/have_binlog_format_row.inc
+# Slow test, don't run during staging part
+-- source include/not_staging.inc
 -- source include/master-slave.inc
+
 let $engine_type=MYISAM;
 -- source extra/rpl_tests/rpl_row_001.test

=== modified file 'mysql-test/suite/rpl/t/rpl_row_mysqlbinlog.test'
--- mysql-test/suite/rpl/t/rpl_row_mysqlbinlog.test	2008-04-03 19:40:10 +0000
+++ mysql-test/suite/rpl/t/rpl_row_mysqlbinlog.test	2009-06-05 15:35:22 +0000
@@ -12,6 +12,8 @@
 -- source include/master-slave.inc
 # This test requires the cp932 charset compiled in
 -- source include/have_cp932.inc
+# Slow test, don't run during staging part
+-- source include/not_staging.inc
 
 # Setup Section
 # we need this for getting fixed timestamps inside of this test

=== modified file 'mysql-test/suite/rpl/t/rpl_row_sp003.test'
--- mysql-test/suite/rpl/t/rpl_row_sp003.test	2007-06-27 12:29:10 +0000
+++ mysql-test/suite/rpl/t/rpl_row_sp003.test	2009-06-05 15:35:22 +0000
@@ -8,6 +8,9 @@
 -- source include/not_ndb_default.inc
 -- source include/have_innodb.inc
 -- source include/have_binlog_format_row.inc
+# Slow test, don't run during staging part
+-- source include/not_staging.inc
 -- source include/master-slave.inc
+
 let $engine_type=INNODB;
 -- source extra/rpl_tests/rpl_row_sp003.test

=== modified file 'mysql-test/suite/rpl/t/rpl_start_stop_slave.test'
--- mysql-test/suite/rpl/t/rpl_start_stop_slave.test	2008-12-12 11:25:36 +0000
+++ mysql-test/suite/rpl/t/rpl_start_stop_slave.test	2009-06-05 15:35:22 +0000
@@ -1,3 +1,5 @@
+# Slow test, don't run during staging part
+-- source include/not_staging.inc
 source include/master-slave.inc;
 
 #

=== modified file 'mysql-test/t/compress.test'
--- mysql-test/t/compress.test	2009-02-09 21:00:15 +0000
+++ mysql-test/t/compress.test	2009-06-05 15:35:22 +0000
@@ -3,8 +3,9 @@
 
 # Can't test with embedded server
 -- source include/not_embedded.inc
-
 -- source include/have_compress.inc
+# Slow test, don't run during staging part
+-- source include/not_staging.inc
 
 # Save the initial number of concurrent sessions
 --source include/count_sessions.inc

=== modified file 'mysql-test/t/count_distinct3.test'
--- mysql-test/t/count_distinct3.test	2006-10-03 07:03:35 +0000
+++ mysql-test/t/count_distinct3.test	2009-06-05 15:35:22 +0000
@@ -3,6 +3,8 @@
 # mysql-4.1
 #
 
+# Slow test
+-- source include/big_test.inc
 --disable_warnings
 DROP TABLE IF EXISTS t1, t2;
 --enable_warnings

=== modified file 'mysql-test/t/index_merge_innodb.test'
--- mysql-test/t/index_merge_innodb.test	2006-09-18 14:55:56 +0000
+++ mysql-test/t/index_merge_innodb.test	2009-06-05 15:35:22 +0000
@@ -10,7 +10,10 @@
 #               include/index_merge*.inc files
 #
 
+# Slow test, don't run during staging part
+--source include/not_staging.inc
 --source include/have_innodb.inc
+
 let $engine_type= InnoDB;
 # InnoDB does not support Merge tables (affects include/index_merge1.inc)
 let $merge_table_support= 0;

=== modified file 'mysql-test/t/information_schema_all_engines.test'
--- mysql-test/t/information_schema_all_engines.test	2009-04-08 16:55:26 +0000
+++ mysql-test/t/information_schema_all_engines.test	2009-06-05 15:35:22 +0000
@@ -4,6 +4,7 @@
 
 --source include/not_embedded.inc
 --source include/have_pbxt.inc
+-- source include/not_staging.inc
 
 use INFORMATION_SCHEMA;
 --replace_result Tables_in_INFORMATION_SCHEMA Tables_in_information_schema

=== modified file 'mysql-test/t/innodb_mysql.test'
--- mysql-test/t/innodb_mysql.test	2009-02-20 09:50:50 +0000
+++ mysql-test/t/innodb_mysql.test	2009-06-05 15:35:22 +0000
@@ -5,6 +5,8 @@
 #               main testing code t/innodb_mysql.test -> include/mix1.inc              
 #
 
+# Slow test, don't run during staging part
+-- source include/not_staging.inc
 -- source include/have_innodb.inc
 let $engine_type= InnoDB;
 let $other_engine_type= MEMORY;

=== modified file 'mysql-test/t/pool_of_threads.test'
--- mysql-test/t/pool_of_threads.test	2009-03-18 15:46:32 +0000
+++ mysql-test/t/pool_of_threads.test	2009-06-05 15:35:22 +0000
@@ -2,7 +2,8 @@
 # and run a number of tests
 
 -- source include/have_pool_of_threads.inc
-
+# Slow test, don't run during staging part
+-- source include/not_staging.inc
 -- source include/common-tests.inc
 
 

=== modified file 'mysql-test/t/preload.test'
--- mysql-test/t/preload.test	2005-07-28 00:22:47 +0000
+++ mysql-test/t/preload.test	2009-06-05 15:35:22 +0000
@@ -2,6 +2,9 @@
 # Testing of PRELOAD
 #
 
+# Slow test, don't run during staging part
+-- source include/not_staging.inc
+
 --disable_warnings
 drop table if exists t1, t2;
 --enable_warnings

=== modified file 'mysql-test/t/ssl.test'
--- mysql-test/t/ssl.test	2009-03-03 20:34:18 +0000
+++ mysql-test/t/ssl.test	2009-06-05 15:35:22 +0000
@@ -2,6 +2,8 @@
 # and run a number of tests
 
 -- source include/have_ssl.inc
+# Slow test, don't run during staging part
+-- source include/not_staging.inc
 
 # Save the initial number of concurrent sessions
 --source include/count_sessions.inc

=== modified file 'mysql-test/t/ssl_compress.test'
--- mysql-test/t/ssl_compress.test	2009-03-03 20:34:18 +0000
+++ mysql-test/t/ssl_compress.test	2009-06-05 15:35:22 +0000
@@ -3,6 +3,7 @@
 
 -- source include/have_ssl.inc
 -- source include/have_compress.inc
+-- source include/not_staging.inc
 
 # Save the initial number of concurrent sessions
 --source include/count_sessions.inc

=== modified file 'mysql-test/valgrind.supp'
--- mysql-test/valgrind.supp	2009-05-22 12:38:50 +0000
+++ mysql-test/valgrind.supp	2009-06-05 15:35:22 +0000
@@ -415,10 +415,40 @@
 }
 
 {
-   dlopen / ptread_cancel_init memory loss on Suse Linux 10.3 32/64 bit
-   Memcheck:Leak
-   fun:*alloc
-   obj:/lib*/ld-*.so
+   dlclose memory loss from plugin variant 4
+   Memcheck:Leak
+   fun:malloc
+   obj:/lib*/ld-*.so
+   obj:/lib*/ld-*.so
+   obj:/lib*/ld-*.so
+   obj:/lib*/libdl-*.so
+   fun:_dl_close
+   fun:_ZL15free_plugin_memP12st_plugin_dl
+   fun:_ZL13plugin_dl_delPK19st_mysql_lex_string
+}
+
+{
+   dlopen / ptread_cancel_init memory loss on Suse Linux 10.3 32/64 bit ver 1
+   Memcheck:Leak
+   fun:*alloc
+   obj:/lib*/ld-*.so
+   obj:/lib*/ld-*.so
+   obj:/lib*/ld-*.so
+   obj:/lib*/ld-*.so
+   obj:/lib*/ld-*.so
+   obj:/lib*/ld-*.so
+   obj:/lib*/libc-*.so
+   obj:/lib*/ld-*.so
+   obj:/lib*/libc-*.so
+   fun:__libc_dlopen_mode
+   fun:pthread_cancel_init
+   fun:_Unwind_ForcedUnwind
+}
+
+{
+   dlopen / ptread_cancel_init memory loss on Suse Linux 10.3 32/64 bit ver 2
+   Memcheck:Leak
+   fun:*alloc
    obj:/lib*/ld-*.so
    obj:/lib*/ld-*.so
    obj:/lib*/ld-*.so

=== modified file 'sql/scheduler.cc'
--- sql/scheduler.cc	2009-03-12 22:27:35 +0000
+++ sql/scheduler.cc	2009-06-05 15:35:22 +0000
@@ -282,8 +282,8 @@
   killed_threads= 0;
   kill_pool_threads= FALSE;
 
-  pthread_mutex_init(&LOCK_event_loop, NULL);
-  pthread_mutex_init(&LOCK_thd_add, NULL);
+  pthread_mutex_init(&LOCK_event_loop, MY_MUTEX_INIT_FAST);
+  pthread_mutex_init(&LOCK_thd_add, MY_MUTEX_INIT_FAST);
 
   /* set up sockets used to add new thds to the event pool */
   if (init_socketpair(thd_add_pair))



--- mysql-test/mysql-test-run.pl	2009-05-12 06:44:01 +0000
+++ mysql-test/mysql-test-run.pl	2009-06-05 15:35:22 +0000
@@ -140,6 +140,7 @@
 our $exe_libtool;
 
 our $opt_big_test= 0;
+our $opt_staging_run= 0;
 
 our @opt_combinations;
 
@@ -844,6 +845,7 @@
              'skip-combinations'        => \&collect_option,
              'experimental=s'           => \$opt_experimental,
 	     'skip-im'                  => \&ignore_option,
+             'staging-run'              => \$opt_staging_run,
 
              # Specify ports
 	     'build-thread|mtr-build-thread=i' => \$opt_build_thread,
@@ -1252,12 +1254,13 @@
   }
 
   # --------------------------------------------------------------------------
   # Big test flags
   # --------------------------------------------------------------------------
    if ( $opt_big_test )
    {
      $ENV{'BIG_TEST'}= 1;
    }
+  $ENV{'STAGING_RUN'}= $opt_staging_run;
 
   # --------------------------------------------------------------------------
   # Gcov flag
@@ -5234,7 +5237,7 @@
   skip-ssl              Dont start server with support for ssl connections
   vs-config             Visual Studio configuration used to create executables
                         (default: MTR_VS_CONFIG environment variable)
-
+  parallel=#            How many parallell test should be run
   config|defaults-file=<config template> Use fixed config template for all
                         tests
   defaults_extra_file=<config template> Extra config template to add to
@@ -5276,6 +5279,8 @@
                         The default is: "$DEFAULT_SUITES"
   skip-rpl              Skip the replication test cases.
   big-test              Also run tests marked as "big"
+  staging-run           Run a limited number of tests (no slow tests). Used
+                        for running staging trees with valgrind.
 
 Options that specify ports
 
@@ -1252,12 +1254,13 @@
 
   # --------------------------------------------------------------------------
-  # Big test flags
+  # Big test and staging_run flags
   # --------------------------------------------------------------------------
    if ( $opt_big_test )

=== modified file 'mysql-test/suite/federated/federated_server.test'
--
lp:maria
https://code.launchpad.net/~maria-captains/maria/5.1

Your team Maria developers is subscribed to branch lp:maria.
To unsubscribe from this branch go to https://code.launchpad.net/~maria-captains/maria/5.1/+edit-subscription.